@@ -62,8 +62,7 @@ getPvalFisher <- function(x, by) {
 
   # Large statistics tend to be very heavy and therefore
   # i need to catch errors in fisher and redo by simulation
-  tryCatch(
-    {
+  tryCatch({
       fisher.test(x, by, workspace = workspace)$p.value
     },
     error = function(err) {
@@ -96,4 +95,4 @@ getPvalChiSq <- function(x, by) {
 #' @export
 getPvalKruskal <- function(x, by) {
   kruskal.test(x, by)$p.value
-}
\ No newline at end of file
+}
